@@ -3,8 +3,8 @@
 
   rbgtkcombo.c -
 
-  $Author: mutoh $
-  $Date: 2004/03/09 17:01:49 $
+  $Author: ggc $
+  $Date: 2007/07/13 16:07:31 $
 
   Copyright (C) 2002,2003 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
@@ -14,6 +14,7 @@
 
 #include "global.h"
 
+#ifndef GTK_DISABLE_DEPRECATED /* Since 2.4 */
 
 static VALUE
 combo_set_popdown_strings(self, ary)
@@ -23,14 +24,11 @@ combo_set_popdown_strings(self, ary)
     GList *glist = NULL;
 
     Check_Type(ary, T_ARRAY);
-    for (i=0; i<RARRAY(ary)->len; i++) {
-	/* check to avoid memory leak */
-	RVAL2CSTR(RARRAY(ary)->ptr[i]);
-    }
-    for (i=0; i<RARRAY(ary)->len; i++) {
-        glist = g_list_append(glist, RVAL2CSTR(RARRAY(ary)->ptr[i]));
+    for (i=0; i<RARRAY_LEN(ary); i++) {
+        glist = g_list_append(glist, RVAL2CSTR(RARRAY_PTR(ary)[i]));
     }
     gtk_combo_set_popdown_strings(GTK_COMBO(RVAL2GOBJ(self)), glist);
+    g_list_free(glist);
     return self;
 }
 
@@ -60,7 +58,7 @@ combo_set_val_in_list(self, val, ok)
     VALUE self, val, ok;
 {
     gtk_combo_set_value_in_list(GTK_COMBO(RVAL2GOBJ(self)),
-				RTEST(val), RTEST(ok));
+				RVAL2CBOOL(val), RVAL2CBOOL(ok));
     return self;
 }
 
@@ -69,7 +67,7 @@ combo_set_use_arrows(self, val)
     VALUE self, val;
 {
     gtk_combo_set_use_arrows(GTK_COMBO(RVAL2GOBJ(self)),
-			     RTEST(val));
+			     RVAL2CBOOL(val));
     return self;
 }
 
@@ -78,7 +76,7 @@ combo_set_use_arrows_always(self, val)
     VALUE self, val;
 {
     gtk_combo_set_use_arrows_always(GTK_COMBO(RVAL2GOBJ(self)),
-                                    RTEST(val));
+                                    RVAL2CBOOL(val));
     return self;
 }
 
@@ -96,10 +94,12 @@ combo_entry(self)
 {
     return GOBJ2RVAL(GTK_COMBO(RVAL2GOBJ(self))->entry);
 }
+#endif
 
 void 
 Init_gtk_combo()
 {
+#ifndef GTK_DISABLE_DEPRECATED  /* Since 2.4 */
     VALUE gCombo = G_DEF_CLASS(GTK_TYPE_COMBO, "Combo", mGtk);
 
     rb_define_method(gCombo, "initialize", combo_initialize, -1);
@@ -112,4 +112,6 @@ Init_gtk_combo()
     rb_define_method(gCombo, "entry", combo_entry, 0);
 
     G_DEF_SETTERS(gCombo);
+#endif
 }
+
